@@ -187,7 +187,11 @@ gtk_style_context_real_changed (GtkStyleContext *context)
   GtkStyleContextPrivate *priv = context->priv;
 
   if (GTK_IS_CSS_WIDGET_NODE (priv->cssnode))
-    _gtk_widget_style_context_invalidated (gtk_css_widget_node_get_widget (GTK_CSS_WIDGET_NODE (priv->cssnode)));
+    {
+      GtkWidget *widget = gtk_css_widget_node_get_widget (GTK_CSS_WIDGET_NODE (priv->cssnode));
+      if (widget != NULL)
+        _gtk_widget_style_context_invalidated (widget);
+    }
 }
 
 static void
@@ -522,7 +526,8 @@ gtk_style_context_push_state (GtkStyleContext *context,
     {
       GtkWidget *widget = gtk_css_widget_node_get_widget (GTK_CSS_WIDGET_NODE (root));
       g_debug ("State %u for %s %p doesn't match state %u set via gtk_style_context_set_state ()",
-               state, gtk_widget_get_name (widget), widget, gtk_css_node_get_state (priv->cssnode));
+               state, (widget == NULL) ? "(null)" : gtk_widget_get_name (widget),
+               widget, gtk_css_node_get_state (priv->cssnode));
     }
   else
     {
@@ -1325,13 +1330,13 @@ gtk_style_context_restore (GtkStyleContext *context)
  * In the CSS file format, a #GtkEntry defining a “search”
  * class, would be matched by:
  *
- * |[
+ * |[ <!-- language="CSS" -->
  * entry.search { ... }
  * ]|
  *
  * While any widget defining a “search” class would be
  * matched by:
- * |[
+ * |[ <!-- language="CSS" -->
  * .search { ... }
  * ]|
  *
@@ -1495,15 +1500,15 @@ _gtk_style_context_check_region_name (const gchar *str)
  * In the CSS file format, a #GtkTreeView defining a “row”
  * region, would be matched by:
  *
- * |[
- * GtkTreeView row { ... }
+ * |[ <!-- language="CSS" -->
+ * treeview row { ... }
  * ]|
  *
  * Pseudo-classes are used for matching @flags, so the two
  * following rules:
- * |[
- * GtkTreeView row:nth-child(even) { ... }
- * GtkTreeView row:nth-child(odd) { ... }
+ * |[ <!-- language="CSS" -->
+ * treeview row:nth-child(even) { ... }
+ * treeview row:nth-child(odd) { ... }
  * ]|
  *
  * would apply to even and odd rows, respectively.
@@ -2257,7 +2262,7 @@ gtk_style_context_lookup_color (GtkStyleContext *context,
  *
  * As a practical example, a #GtkButton notifying a state transition on
  * the prelight state:
- * |[<!-- language="C" -->
+ * |[ <!-- language="C" -->
  * gtk_style_context_notify_state_change (context,
  *                                        gtk_widget_get_window (widget),
  *                                        NULL,
@@ -2266,12 +2271,12 @@ gtk_style_context_lookup_color (GtkStyleContext *context,
  * ]|
  *
  * Can be handled in the CSS file like this:
- * |[
- * GtkButton {
+ * |[ <!-- language="CSS" -->
+ * button {
  *     background-color: #f00
  * }
  *
- * GtkButton:hover {
+ * button:hover {
  *     background-color: #fff;
  *     transition: 200ms linear
  * }
